> :mag_right: parse blockchain data in search of threat indicators.

This project was first meant to enable [Forta network of detection bots][forta-explorer].

## Table of Contents

- [Table of Contents](#table-of-contents)
- [Installation](#installation)
- [Usage](#usage)
- [Development](#development)
  - [TODO](#todo)
  - [Community](#community)
- [License](#license)

## Installation

## Usage

## Development

Contributions welcome!

### TODO

See [TODO](TODO.md).

## License

Licensed under the [aGPL v3](LICENSE).

[forta-explorer]: https://explorer.forta.network/
